@@ -15,13 +15,13 @@ class MockConnection(object):
         self.is_http2 = http_version == "HTTP/2"
         self.stream_count = 0
 
-    async def arequest(
+    async def handle_async_request(
         self,
         method: bytes,
         url: URL,
         headers: Headers = None,
         stream: httpcore.AsyncByteStream = None,
-        ext: dict = None,
+        extensions: dict = None,
     ) -> Tuple[int, Headers, httpcore.AsyncByteStream, dict]:
         self.state = ConnectionState.ACTIVE
         self.stream_count += 1
@@ -44,12 +44,21 @@ class MockConnection(object):
         pass
 
     def info(self) -> str:
-        return str(self.state)
+        return self.state.name
 
-    def mark_as_ready(self) -> None:
-        self.state = ConnectionState.READY
+    def is_available(self):
+        if self.is_http11:
+            return self.state == ConnectionState.IDLE
+        else:
+            return self.state != ConnectionState.CLOSED
 
-    def is_socket_readable(self) -> bool:
+    def should_close(self):
+        return False
+
+    def is_idle(self):
+        return self.state == ConnectionState.IDLE
+
+    def is_closed(self):
         return False
 
 
@@ -80,23 +89,35 @@ async def test_sequential_requests(http_version) -> None:
         info = await http.get_connection_info()
         assert info == {}
 
-        response = await http.arequest(b"GET", (b"http", b"example.org", None, b"/"))
-        status_code, headers, stream, ext = response
+        response = await http.handle_async_request(
+            method=b"GET",
+            url=(b"http", b"example.org", None, b"/"),
+            headers=[],
+            stream=httpcore.ByteStream(b""),
+            extensions={},
+        )
+        status_code, headers, stream, extensions = response
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.ACTIVE"]}
+        assert info == {"http://example.org": ["ACTIVE"]}
 
         await read_body(stream)
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.IDLE"]}
+        assert info == {"http://example.org": ["IDLE"]}
 
-        response = await http.arequest(b"GET", (b"http", b"example.org", None, b"/"))
-        status_code, headers, stream, ext = response
+        response = await http.handle_async_request(
+            method=b"GET",
+            url=(b"http", b"example.org", None, b"/"),
+            headers=[],
+            stream=httpcore.ByteStream(b""),
+            extensions={},
+        )
+        status_code, headers, stream, extensions = response
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.ACTIVE"]}
+        assert info == {"http://example.org": ["ACTIVE"]}
 
         await read_body(stream)
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.IDLE"]}
+        assert info == {"http://example.org": ["IDLE"]}
 
 
 @pytest.mark.trio
@@ -105,29 +126,35 @@ async def test_concurrent_requests_h11() -> None:
         info = await http.get_connection_info()
         assert info == {}
 
-        response_1 = await http.arequest(b"GET", (b"http", b"example.org", None, b"/"))
+        response_1 = await http.handle_async_request(
+            method=b"GET",
+            url=(b"http", b"example.org", None, b"/"),
+            headers=[],
+            stream=httpcore.ByteStream(b""),
+            extensions={},
+        )
         status_code_1, headers_1, stream_1, ext_1 = response_1
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.ACTIVE"]}
+        assert info == {"http://example.org": ["ACTIVE"]}
 
-        response_2 = await http.arequest(b"GET", (b"http", b"example.org", None, b"/"))
+        response_2 = await http.handle_async_request(
+            method=b"GET",
+            url=(b"http", b"example.org", None, b"/"),
+            headers=[],
+            stream=httpcore.ByteStream(b""),
+            extensions={},
+        )
         status_code_2, headers_2, stream_2, ext_2 = response_2
         info = await http.get_connection_info()
-        assert info == {
-            "http://example.org": ["ConnectionState.ACTIVE", "ConnectionState.ACTIVE"]
-        }
+        assert info == {"http://example.org": ["ACTIVE", "ACTIVE"]}
 
         await read_body(stream_1)
         info = await http.get_connection_info()
-        assert info == {
-            "http://example.org": ["ConnectionState.ACTIVE", "ConnectionState.IDLE"]
-        }
+        assert info == {"http://example.org": ["ACTIVE", "IDLE"]}
 
         await read_body(stream_2)
         info = await http.get_connection_info()
-        assert info == {
-            "http://example.org": ["ConnectionState.IDLE", "ConnectionState.IDLE"]
-        }
+        assert info == {"http://example.org": ["IDLE", "IDLE"]}
 
 
 @pytest.mark.trio
@@ -136,20 +163,32 @@ async def test_concurrent_requests_h2() -> None:
         info = await http.get_connection_info()
         assert info == {}
 
-        response_1 = await http.arequest(b"GET", (b"http", b"example.org", None, b"/"))
+        response_1 = await http.handle_async_request(
+            method=b"GET",
+            url=(b"http", b"example.org", None, b"/"),
+            headers=[],
+            stream=httpcore.ByteStream(b""),
+            extensions={},
+        )
         status_code_1, headers_1, stream_1, ext_1 = response_1
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.ACTIVE"]}
+        assert info == {"http://example.org": ["ACTIVE"]}
 
-        response_2 = await http.arequest(b"GET", (b"http", b"example.org", None, b"/"))
+        response_2 = await http.handle_async_request(
+            method=b"GET",
+            url=(b"http", b"example.org", None, b"/"),
+            headers=[],
+            stream=httpcore.ByteStream(b""),
+            extensions={},
+        )
         status_code_2, headers_2, stream_2, ext_2 = response_2
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.ACTIVE"]}
+        assert info == {"http://example.org": ["ACTIVE"]}
 
         await read_body(stream_1)
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.ACTIVE"]}
+        assert info == {"http://example.org": ["ACTIVE"]}
 
         await read_body(stream_2)
         info = await http.get_connection_info()
-        assert info == {"http://example.org": ["ConnectionState.IDLE"]}
+        assert info == {"http://example.org": ["IDLE"]}
